# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""


from typing import List, Optional

from pydantic.v1 import Field, StrictInt, validate_arguments
from typing_extensions import Annotated

from earnix_elevate.clients.data.api_client import ApiClient
from earnix_elevate.clients.data.api_response import ApiResponse
from earnix_elevate.clients.data.exceptions import ApiTypeError
from earnix_elevate.clients.data.models.create_recipe_request import CreateRecipeRequest
from earnix_elevate.clients.data.models.create_recipe_version_request import (
    CreateRecipeVersionRequest,
)
from earnix_elevate.clients.data.models.dataset_version_usage import DatasetVersionUsage
from earnix_elevate.clients.data.models.list_query import ListQuery
from earnix_elevate.clients.data.models.recipe_response import RecipeResponse
from earnix_elevate.clients.data.models.recipe_version_response import (
    RecipeVersionResponse,
)
from earnix_elevate.clients.data.models.recipes_response import RecipesResponse
from earnix_elevate.clients.data.models.update_recipe_request import UpdateRecipeRequest
from earnix_elevate.clients.data.models.update_recipe_version_request import (
    UpdateRecipeVersionRequest,
)


class RecipeServiceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_recipe(
        self,
        create_recipe_request: Annotated[
            CreateRecipeRequest,
            Field(
                ...,
                description="Request body containing the configuration details needed to create a new Recipe, including name, description, language, type, and initial code",
            ),
        ],
        **kwargs,
    ) -> RecipeResponse:
        """Create new recipe

        Creates a new recipe with version 1. The recipe can then be reused across multiple datasets.

        :param create_recipe_request: Request body containing the configuration details needed to create a new Recipe, including name, description, language, type, and initial code (required)
        :type create_recipe_request: CreateRecipeRequest
        :return: Returns the result object.
        :rtype: RecipeResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the create_recipe_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.create_recipe_with_http_info(create_recipe_request, **kwargs)

    @validate_arguments
    def create_recipe_with_http_info(
        self,
        create_recipe_request: Annotated[
            CreateRecipeRequest,
            Field(
                ...,
                description="Request body containing the configuration details needed to create a new Recipe, including name, description, language, type, and initial code",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Create new recipe

        Creates a new recipe with version 1. The recipe can then be reused across multiple datasets.

        :param create_recipe_request: Request body containing the configuration details needed to create a new Recipe, including name, description, language, type, and initial code (required)
        :type create_recipe_request: CreateRecipeRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(RecipeResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["create_recipe_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_recipe" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["create_recipe_request"] is not None:
            _body_params = _params["create_recipe_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "201": "RecipeResponse",
        }

        return self.api_client.call_api(
            "/v1/recipes",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def create_recipe_version(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        create_recipe_version_request: Annotated[
            CreateRecipeVersionRequest,
            Field(
                ...,
                description="Request body containing optional code for creating a new version of a Recipe. If code is not provided, it will be copied from the latest version",
            ),
        ],
        **kwargs,
    ) -> RecipeVersionResponse:
        """Create new recipe version

        Creates new RecipeVersionEntity with versionNumber = latestVersionNumber + 1. If code is provided in the request, uses that code for the new version. If code is not provided, copies code from the latest version. Updates RecipeEntity.latestVersionNumber. Returns RecipeVersionResponse.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param create_recipe_version_request: Request body containing optional code for creating a new version of a Recipe. If code is not provided, it will be copied from the latest version (required)
        :type create_recipe_version_request: CreateRecipeVersionRequest
        :return: Returns the result object.
        :rtype: RecipeVersionResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the create_recipe_version_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.create_recipe_version_with_http_info(
            recipe_id, create_recipe_version_request, **kwargs
        )

    @validate_arguments
    def create_recipe_version_with_http_info(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        create_recipe_version_request: Annotated[
            CreateRecipeVersionRequest,
            Field(
                ...,
                description="Request body containing optional code for creating a new version of a Recipe. If code is not provided, it will be copied from the latest version",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Create new recipe version

        Creates new RecipeVersionEntity with versionNumber = latestVersionNumber + 1. If code is provided in the request, uses that code for the new version. If code is not provided, copies code from the latest version. Updates RecipeEntity.latestVersionNumber. Returns RecipeVersionResponse.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param create_recipe_version_request: Request body containing optional code for creating a new version of a Recipe. If code is not provided, it will be copied from the latest version (required)
        :type create_recipe_version_request: CreateRecipeVersionRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(RecipeVersionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["recipe_id", "create_recipe_version_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_recipe_version" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["recipe_id"] is not None:
            _path_params["recipe-id"] = _params["recipe_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["create_recipe_version_request"] is not None:
            _body_params = _params["create_recipe_version_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "201": "RecipeVersionResponse",
        }

        return self.api_client.call_api(
            "/v1/recipes/{recipe-id}/versions",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_recipe(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        **kwargs,
    ) -> RecipeResponse:
        """Get recipe

        Returns Recipe - recipe base information from RecipeEntity (id, name, description, language, latestVersionNumber). Does NOT include version-specific code. To get code, use GET /v1/recipes/{recipe-id}/versions/{version-number}

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :return: Returns the result object.
        :rtype: RecipeResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_recipe_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.get_recipe_with_http_info(recipe_id, **kwargs)

    @validate_arguments
    def get_recipe_with_http_info(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Get recipe

        Returns Recipe - recipe base information from RecipeEntity (id, name, description, language, latestVersionNumber). Does NOT include version-specific code. To get code, use GET /v1/recipes/{recipe-id}/versions/{version-number}

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(RecipeResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["recipe_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recipe" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["recipe_id"] is not None:
            _path_params["recipe-id"] = _params["recipe_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "RecipeResponse",
        }

        return self.api_client.call_api(
            "/v1/recipes/{recipe-id}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_recipe_version(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        version_number: Annotated[
            StrictInt, Field(..., description="Version number of the recipe")
        ],
        **kwargs,
    ) -> RecipeVersionResponse:
        """Get specific recipe version

        Returns RecipeVersionResponse - combines RecipeEntity base fields (via Recipe) with specific RecipeVersionEntity. Allows retrieving any historical version including code and lock status.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param version_number: Version number of the recipe (required)
        :type version_number: int
        :return: Returns the result object.
        :rtype: RecipeVersionResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_recipe_version_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.get_recipe_version_with_http_info(
            recipe_id, version_number, **kwargs
        )

    @validate_arguments
    def get_recipe_version_with_http_info(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        version_number: Annotated[
            StrictInt, Field(..., description="Version number of the recipe")
        ],
        **kwargs,
    ) -> ApiResponse:
        """Get specific recipe version

        Returns RecipeVersionResponse - combines RecipeEntity base fields (via Recipe) with specific RecipeVersionEntity. Allows retrieving any historical version including code and lock status.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param version_number: Version number of the recipe (required)
        :type version_number: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(RecipeVersionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["recipe_id", "version_number"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recipe_version" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["recipe_id"] is not None:
            _path_params["recipe-id"] = _params["recipe_id"]

        if _params["version_number"] is not None:
            _path_params["version-number"] = _params["version_number"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "RecipeVersionResponse",
        }

        return self.api_client.call_api(
            "/v1/recipes/{recipe-id}/versions/{version-number}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_recipe_version_usage(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        version_number: Annotated[
            StrictInt, Field(..., description="Version number of the recipe")
        ],
        **kwargs,
    ) -> List[DatasetVersionUsage]:
        """Get recipe version usage details

        Returns RecipeUsageResponse - lists all dataset versions using this specific recipe version with full dataset version metadata (dataset ID, version, name, status, node ID, created/modified info). Includes DRAFT and RELEASED dataset versions.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param version_number: Version number of the recipe (required)
        :type version_number: int
        :return: Returns the result object.
        :rtype: List[DatasetVersionUsage]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_recipe_version_usage_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.get_recipe_version_usage_with_http_info(
            recipe_id, version_number, **kwargs
        )

    @validate_arguments
    def get_recipe_version_usage_with_http_info(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        version_number: Annotated[
            StrictInt, Field(..., description="Version number of the recipe")
        ],
        **kwargs,
    ) -> ApiResponse:
        """Get recipe version usage details

        Returns RecipeUsageResponse - lists all dataset versions using this specific recipe version with full dataset version metadata (dataset ID, version, name, status, node ID, created/modified info). Includes DRAFT and RELEASED dataset versions.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param version_number: Version number of the recipe (required)
        :type version_number: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(List[DatasetVersionUsage], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["recipe_id", "version_number"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_recipe_version_usage" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["recipe_id"] is not None:
            _path_params["recipe-id"] = _params["recipe_id"]

        if _params["version_number"] is not None:
            _path_params["version-number"] = _params["version_number"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "List[DatasetVersionUsage]",
        }

        return self.api_client.call_api(
            "/v1/recipes/{recipe-id}/versions/{version-number}/usage",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_recipe_versions(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        **kwargs,
    ) -> List[RecipeVersionResponse]:
        """List all versions of recipe

        Returns all versions of the recipe sorted by version number descending. Includes versionNumber, code, and isLocked for each version.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :return: Returns the result object.
        :rtype: List[RecipeVersionResponse]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the list_recipe_versions_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.list_recipe_versions_with_http_info(recipe_id, **kwargs)

    @validate_arguments
    def list_recipe_versions_with_http_info(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        **kwargs,
    ) -> ApiResponse:
        """List all versions of recipe

        Returns all versions of the recipe sorted by version number descending. Includes versionNumber, code, and isLocked for each version.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(List[RecipeVersionResponse], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["recipe_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_recipe_versions" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["recipe_id"] is not None:
            _path_params["recipe-id"] = _params["recipe_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "List[RecipeVersionResponse]",
        }

        return self.api_client.call_api(
            "/v1/recipes/{recipe-id}/versions",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_recipes(
        self,
        list_query: Annotated[
            Optional[ListQuery], Field(description="List query parameters")
        ] = None,
        **kwargs,
    ) -> RecipesResponse:
        """List all recipes with latest version

        Returns array of recipes with nested latest version. Each item includes base info (recipeId, name, description, language, type) AND latestVersion object containing (versionNumber, code, isLocked).

        :param list_query: List query parameters
        :type list_query: ListQuery
        :return: Returns the result object.
        :rtype: RecipesResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the list_recipes_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.list_recipes_with_http_info(list_query, **kwargs)

    @validate_arguments
    def list_recipes_with_http_info(
        self,
        list_query: Annotated[
            Optional[ListQuery], Field(description="List query parameters")
        ] = None,
        **kwargs,
    ) -> ApiResponse:
        """List all recipes with latest version

        Returns array of recipes with nested latest version. Each item includes base info (recipeId, name, description, language, type) AND latestVersion object containing (versionNumber, code, isLocked).

        :param list_query: List query parameters
        :type list_query: ListQuery
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(RecipesResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["list_query"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_recipes" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get("list_query") is not None:
            _query_params.append(("listQuery", _params["list_query"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "RecipesResponse",
        }

        return self.api_client.call_api(
            "/v1/recipes",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def update_recipe(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        update_recipe_request: Annotated[
            UpdateRecipeRequest,
            Field(
                ...,
                description="Request body containing the updated configuration for an existing Recipe, including metadata changes such as name and description",
            ),
        ],
        **kwargs,
    ) -> RecipeResponse:
        """Update recipe

        Updates RecipeEntity fields ONLY: name, description. These are shared across all versions and can ALWAYS be updated regardless of lock status. Does NOT update code. Returns Recipe.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param update_recipe_request: Request body containing the updated configuration for an existing Recipe, including metadata changes such as name and description (required)
        :type update_recipe_request: UpdateRecipeRequest
        :return: Returns the result object.
        :rtype: RecipeResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the update_recipe_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.update_recipe_with_http_info(
            recipe_id, update_recipe_request, **kwargs
        )

    @validate_arguments
    def update_recipe_with_http_info(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        update_recipe_request: Annotated[
            UpdateRecipeRequest,
            Field(
                ...,
                description="Request body containing the updated configuration for an existing Recipe, including metadata changes such as name and description",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Update recipe

        Updates RecipeEntity fields ONLY: name, description. These are shared across all versions and can ALWAYS be updated regardless of lock status. Does NOT update code. Returns Recipe.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param update_recipe_request: Request body containing the updated configuration for an existing Recipe, including metadata changes such as name and description (required)
        :type update_recipe_request: UpdateRecipeRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(RecipeResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["recipe_id", "update_recipe_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_recipe" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["recipe_id"] is not None:
            _path_params["recipe-id"] = _params["recipe_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["update_recipe_request"] is not None:
            _body_params = _params["update_recipe_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "RecipeResponse",
        }

        return self.api_client.call_api(
            "/v1/recipes/{recipe-id}",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def update_recipe_version(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        version_number: Annotated[
            StrictInt, Field(..., description="Version number of the recipe")
        ],
        update_recipe_version_request: Annotated[
            UpdateRecipeVersionRequest,
            Field(
                ...,
                description="Request body containing the updated code for a specific Recipe version. Can only update code if the version is not locked",
            ),
        ],
        **kwargs,
    ) -> RecipeVersionResponse:
        """Update recipe version

        Update version-specific code. Can ONLY update code if version is NOT locked (not used in released datasets). If version is locked, returns 409 CONFLICT with suggestion to create new version. This is the ONLY way to update recipe code.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param version_number: Version number of the recipe (required)
        :type version_number: int
        :param update_recipe_version_request: Request body containing the updated code for a specific Recipe version. Can only update code if the version is not locked (required)
        :type update_recipe_version_request: UpdateRecipeVersionRequest
        :return: Returns the result object.
        :rtype: RecipeVersionResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the update_recipe_version_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.update_recipe_version_with_http_info(
            recipe_id, version_number, update_recipe_version_request, **kwargs
        )

    @validate_arguments
    def update_recipe_version_with_http_info(
        self,
        recipe_id: Annotated[
            StrictInt,
            Field(..., description="Unique identifier of the recipe to operate on"),
        ],
        version_number: Annotated[
            StrictInt, Field(..., description="Version number of the recipe")
        ],
        update_recipe_version_request: Annotated[
            UpdateRecipeVersionRequest,
            Field(
                ...,
                description="Request body containing the updated code for a specific Recipe version. Can only update code if the version is not locked",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Update recipe version

        Update version-specific code. Can ONLY update code if version is NOT locked (not used in released datasets). If version is locked, returns 409 CONFLICT with suggestion to create new version. This is the ONLY way to update recipe code.

        :param recipe_id: Unique identifier of the recipe to operate on (required)
        :type recipe_id: int
        :param version_number: Version number of the recipe (required)
        :type version_number: int
        :param update_recipe_version_request: Request body containing the updated code for a specific Recipe version. Can only update code if the version is not locked (required)
        :type update_recipe_version_request: UpdateRecipeVersionRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(RecipeVersionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["recipe_id", "version_number", "update_recipe_version_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_recipe_version" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["recipe_id"] is not None:
            _path_params["recipe-id"] = _params["recipe_id"]

        if _params["version_number"] is not None:
            _path_params["version-number"] = _params["version_number"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["update_recipe_version_request"] is not None:
            _body_params = _params["update_recipe_version_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "RecipeVersionResponse",
        }

        return self.api_client.call_api(
            "/v1/recipes/{recipe-id}/versions/{version-number}",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
import re
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictInt, constr, validator


class SourceNodeDefinition(BaseModel):
    """
    `SourceNodeDefinition`

    Defines a source node and its alias binding for a recipe node
    """

    source_node_id: StrictInt = Field(
        default=...,
        alias="sourceNodeId",
        description="ID of the source node in the transformation graph",
    )
    alias: Optional[constr(strict=True, max_length=64, min_length=1)] = Field(
        default=None,
        description='Alias for this source. Optional for single-source recipes (defaults to "CurrentTable"). Required for multi-source recipes (must match one of the recipe\'s aliases). ',
    )
    __properties = ["sourceNodeId", "alias"]

    @validator("alias")
    def alias_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[a-zA-Z][a-zA-Z0-9_]*$", value):
            raise ValueError(
                r"must validate the regular expression /^[a-zA-Z][a-zA-Z0-9_]*$/"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SourceNodeDefinition:
        """Create an instance of SourceNodeDefinition from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SourceNodeDefinition:
        """Create an instance of SourceNodeDefinition from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SourceNodeDefinition.parse_obj(obj)

        _obj = SourceNodeDefinition.parse_obj(
            {"source_node_id": obj.get("sourceNodeId"), "alias": obj.get("alias")}
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Umon API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from datetime import datetime
from typing import Optional

from pydantic.v1 import (
    BaseModel,
    Field,
    StrictBool,
    StrictInt,
    StrictStr,
    conlist,
    constr,
)


class CreateQuotaRequest(BaseModel):
    """
    `CreateQuotaRequest`

    Request to create a new quota contract
    """

    name: Optional[constr(strict=True, max_length=100, min_length=3)] = Field(
        default=None,
        description="Name of the entity for identification and display purposes",
    )
    description: Optional[constr(strict=True, max_length=500)] = Field(
        default=None,
        description="Optional detailed description providing additional context about the entity",
    )
    tags: Optional[conlist(StrictStr, unique_items=True)] = Field(
        default=None,
        description="List of unique tags for categorizing and organizing the entity",
    )
    start_date: Optional[datetime] = Field(
        default=None,
        alias="startDate",
        description="Start date of quota contract (inclusive)",
    )
    end_date: Optional[datetime] = Field(
        default=None,
        alias="endDate",
        description="End date of quota contract (exclusive)",
    )
    cpu_time_hours: Optional[StrictInt] = Field(
        default=None, alias="cpuTimeHours", description="CPU hours quota"
    )
    data_transfer_gb: Optional[StrictInt] = Field(
        default=None, alias="dataTransferGb", description="Data transfer quota in GB"
    )
    overage_allowed: Optional[StrictBool] = Field(
        default=None,
        alias="overageAllowed",
        description="Whether overage beyond quota is allowed",
    )
    __properties = [
        "name",
        "description",
        "tags",
        "startDate",
        "endDate",
        "cpuTimeHours",
        "dataTransferGb",
        "overageAllowed",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateQuotaRequest:
        """Create an instance of CreateQuotaRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateQuotaRequest:
        """Create an instance of CreateQuotaRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateQuotaRequest.parse_obj(obj)

        _obj = CreateQuotaRequest.parse_obj(
            {
                "name": obj.get("name"),
                "description": obj.get("description"),
                "tags": obj.get("tags"),
                "start_date": obj.get("startDate"),
                "end_date": obj.get("endDate"),
                "cpu_time_hours": obj.get("cpuTimeHours"),
                "data_transfer_gb": obj.get("dataTransferGb"),
                "overage_allowed": obj.get("overageAllowed"),
            }
        )
        return _obj



# ruff: noqa: F401

from .clients.data import (
    AddDatasetDataTableNodeRequest,
    AddDatasetNodeRequest,
    AddDatasetRecipeNodeRequest,
    ConversationIdResponse,
    ConversationMessageResponse,
    ConversationResponse,
    CreateDatasetRequest,
    CreateDatasetVersionRequest,
    CreateDataTableRequest,
    CreateRecipeRequest,
    CreateRecipeVersionRequest,
    DatasetDataTableNodeResponse,
    DatasetEdgeResponse,
    DatasetEdgesResponse,
    DatasetNodeResponse,
    DatasetNodesResponse,
    DatasetRecipeNodeResponse,
    DatasetResponse,
    DatasetsResponse,
    DataTableResponse,
    DataTablesResponse,
    DataVersionResponse,
    ExecuteRecipeRequest,
    ExportPartResultPairResponse,
    ExportS3JobStatusResponse,
    ExportS3PartJobStatusResponse,
    ExportS3PartRequest,
    ExportS3PartResponse,
    ExportS3Request,
    ExportS3Response,
    ExportS3StatusResponse,
    LeanTransformationGraphResponse,
    ListQuery,
    RecipeCodeResponse,
    RecipeResponse,
    RecipesResponse,
    RecipeStatusResponse,
    RecipeVersionResponse,
    SchemaAnalysisStatusResponse,
    SinkNodesResponse,
    TransformationGraphResponse,
    TransformationGraphWrapperResponse,
    UpdateDatasetDataTableNodeRequest,
    UpdateDatasetNodeRequest,
    UpdateDatasetRecipeNodeRequest,
    UpdateDatasetRequest,
    UpdateDataTableRequest,
    UpdateRecipeRequest,
    UpdateRecipeVersionRequest,
    UserMessageRequest,
)
from .clients.imx import (
    BrowseBucketDataSourceRequest,
    BrowseBucketDataSourceResponse,
    BucketDataSourceResponse,
    ClientCredentialsAuthRequest,
    ClientCredentialsAuthResponse,
    ConnectionResponse,
    ConnectionsResponse,
    CreateBucketDataSourceRequest,
    CreateConnectionRequest,
    CreateDataSourceRequest,
    CreateDataTargetRequest,
    CreateDeltaSharingConnectionRequest,
    CreateDeltaSharingDataSourceRequest,
    CreateExportRequest,
    CreateExportResponse,
    CreatePriceItDataTargetRequest,
    CreatePriceItDimConnectionRequest,
    CreateRDBMSDataSourceRequest,
    CreateS3ConnectionRequest,
    CreateS3DataTargetRequest,
    CreateSnowflakeConnectionRequest,
    DataSourceResponse,
    DataSourcesResponse,
    DataTargetResponse,
    DataTargetsResponse,
    DeltaSharingAuthRequest,
    DeltaSharingAuthResponse,
    DeltaSharingConnectionResponse,
    DeltaSharingDataSourceResponse,
    DeltaSharingJsonProfileAuthRequest,
    DeltaSharingJsonProfileAuthResponse,
    ExportResponse,
    ExportsResponse,
    MergeConnectionRequest,
    MergeDeltaSharingConnectionRequest,
    MergePriceItDimConnectionRequest,
    MergeS3ConnectionRequest,
    MergeSnowflakeConnectionRequest,
    OAuthRequest,
    OAuthResponse,
    PriceItDataTargetResponse,
    PriceItDimConnectionResponse,
    RDBMSDataSourceResponse,
    S3AuthRequest,
    S3AuthResponse,
    S3ConnectionResponse,
    S3DataTargetResponse,
    S3SecretKeyAuthRequest,
    S3SecretKeyAuthResponse,
    SnowflakeAuthRequest,
    SnowflakeAuthResponse,
    SnowflakeClientCredentialsAuthRequest,
    SnowflakeClientCredentialsAuthResponse,
    SnowflakeConnectionResponse,
    SnowflakePasswordAuthRequest,
    SnowflakePasswordAuthResponse,
    TableDetailsResponse,
    TestConnectionRequest,
    TestDeltaSharingConnectionRequest,
    TestPriceItDimConnectionRequest,
    TestRDBMSDataSourceRequest,
    TestS3ConnectionRequest,
    TestSnowflakeConnectionRequest,
    TestUpdatedConnectionRequest,
    TestUpdatedDeltaSharingConnectionRequest,
    TestUpdatedPriceItDimConnectionRequest,
    TestUpdatedS3ConnectionRequest,
    TestUpdatedSnowflakeConnectionRequest,
    UpdateBucketDataSourceRequest,
    UpdateConnectionRequest,
    UpdateConnectionTypeMappingRequest,
    UpdateDataSourceRequest,
    UpdateDataTargetRequest,
    UpdateDeltaSharingConnectionRequest,
    UpdateDeltaSharingDataSourceRequest,
    UpdatePriceItDataTargetRequest,
    UpdatePriceItDimConnectionRequest,
    UpdateRDBMSDataSourceRequest,
    UpdateS3ConnectionRequest,
    UpdateS3DataTargetRequest,
    UpdateSnowflakeConnectionRequest,
)
from .clients.umon import (
    CreateQuotaRequest,
    QuotaContractResponse,
    QuotaOverageAllowedRequest,
    UsageMonitoringResponse,
)
from .core.data import DatasetService, DataTableService, ExportJobService, RecipeService
from .core.imx import (
    ConnectionService,
    DataSourceService,
    DataTargetService,
    ExportService,
)
from .core.umon import QuotaService, UsageMonitoringService



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from importlib import import_module
from typing import TYPE_CHECKING, Union

from pydantic.v1 import BaseModel, Field, StrictStr

if TYPE_CHECKING:
    from earnix_elevate.clients.imx.models.test_delta_sharing_connection_request import (
        TestDeltaSharingConnectionRequest,
    )
    from earnix_elevate.clients.imx.models.test_price_it_dim_connection_request import (
        TestPriceItDimConnectionRequest,
    )
    from earnix_elevate.clients.imx.models.test_s3_connection_request import (
        TestS3ConnectionRequest,
    )
    from earnix_elevate.clients.imx.models.test_snowflake_connection_request import (
        TestSnowflakeConnectionRequest,
    )


class TestConnectionRequest(BaseModel):
    """
    `TestConnectionRequest`

    Request to test a Connection configuration by attempting to establish a connection using the provided authentication details and connection parameters.
    """

    type: StrictStr = Field(
        default=...,
        description="The type of Connection to test (s3 for S3 storage, snowflake for Snowflake database)",
    )
    __properties = ["type"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    # JSON field name that stores the object type
    __discriminator_property_name = "type"

    # discriminator mappings
    __discriminator_value_class_map = {
        "delta_sharing": "TestDeltaSharingConnectionRequest",
        "priceit_dim": "TestPriceItDimConnectionRequest",
        "s3": "TestS3ConnectionRequest",
        "snowflake": "TestSnowflakeConnectionRequest",
    }

    @classmethod
    def get_discriminator_value(cls, obj: dict) -> str:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(
        cls, json_str: str
    ) -> Union[
        TestDeltaSharingConnectionRequest,
        TestPriceItDimConnectionRequest,
        TestS3ConnectionRequest,
        TestSnowflakeConnectionRequest,
    ]:
        """Create an instance of TestConnectionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(
        cls, obj: dict
    ) -> Union[
        TestDeltaSharingConnectionRequest,
        TestPriceItDimConnectionRequest,
        TestS3ConnectionRequest,
        TestSnowflakeConnectionRequest,
    ]:
        """Create an instance of TestConnectionRequest from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type == "TestDeltaSharingConnectionRequest":
            return import_module(
                "earnix_elevate.clients.imx.models.test_delta_sharing_connection_request"
            ).TestDeltaSharingConnectionRequest.from_dict(obj)
        if object_type == "TestPriceItDimConnectionRequest":
            return import_module(
                "earnix_elevate.clients.imx.models.test_price_it_dim_connection_request"
            ).TestPriceItDimConnectionRequest.from_dict(obj)
        if object_type == "TestS3ConnectionRequest":
            return import_module(
                "earnix_elevate.clients.imx.models.test_s3_connection_request"
            ).TestS3ConnectionRequest.from_dict(obj)
        if object_type == "TestSnowflakeConnectionRequest":
            return import_module(
                "earnix_elevate.clients.imx.models.test_snowflake_connection_request"
            ).TestSnowflakeConnectionRequest.from_dict(obj)
        raise ValueError(
            "TestConnectionRequest failed to lookup discriminator value from "
            + json.dumps(obj)
            + ". Discriminator property name: "
            + cls.__discriminator_property_name
            + ", mapping: "
            + json.dumps(cls.__discriminator_value_class_map)
        )



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint

from pydantic.v1 import Field

from earnix_elevate.clients.imx.models.delta_sharing_auth_request import (
    DeltaSharingAuthRequest,
)
from earnix_elevate.clients.imx.models.test_connection_request import (
    TestConnectionRequest,
)


class TestDeltaSharingConnectionRequest(TestConnectionRequest):
    """
    `TestDeltaSharingConnectionRequest`

    Request to test an DeltaSharing Connection by attempting to authenticate and access the DeltaSharing service using the provided credentials and endpoint configuration.
    """

    auth: DeltaSharingAuthRequest = Field(...)
    __properties = ["type", "auth"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TestDeltaSharingConnectionRequest:
        """Create an instance of TestDeltaSharingConnectionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of auth
        if self.auth:
            _dict["auth"] = self.auth.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TestDeltaSharingConnectionRequest:
        """Create an instance of TestDeltaSharingConnectionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TestDeltaSharingConnectionRequest.parse_obj(obj)

        _obj = TestDeltaSharingConnectionRequest.parse_obj(
            {
                "type": obj.get("type"),
                "auth": DeltaSharingAuthRequest.from_dict(obj.get("auth"))
                if obj.get("auth") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictInt, conlist, constr


class UpdateRecipeVersionRequest(BaseModel):
    """
    `UpdateRecipeVersionRequest`

    Updates version-specific code (can only update if version is NOT locked)
    """

    code: constr(strict=True, min_length=8) = Field(
        default=..., description="SQL code that defines the data transformation logic"
    )
    version_number: StrictInt = Field(
        default=...,
        alias="versionNumber",
        description="Recipe version number (current version used by this node)",
    )
    aliases: Optional[
        conlist(
            constr(strict=True, max_length=64, min_length=1), max_items=10, min_items=1
        )
    ] = Field(
        default=None,
        description='Table aliases used in SQL code for recipe transformations. Single-source recipes have 1 alias (e.g. "CurrentTable" for backward compatibility, or any valid name). Multi-source recipes have 2-10 aliases matching table names in SQL. ',
    )
    lock_version: StrictInt = Field(
        default=..., alias="lockVersion", description="Optimistic locking version"
    )
    __properties = ["code", "versionNumber", "aliases", "lockVersion"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdateRecipeVersionRequest:
        """Create an instance of UpdateRecipeVersionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdateRecipeVersionRequest:
        """Create an instance of UpdateRecipeVersionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdateRecipeVersionRequest.parse_obj(obj)

        _obj = UpdateRecipeVersionRequest.parse_obj(
            {
                "code": obj.get("code"),
                "version_number": obj.get("versionNumber"),
                "aliases": obj.get("aliases"),
                "lock_version": obj.get("lockVersion"),
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from datetime import datetime
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictBool

from earnix_elevate.clients.data.models.job_execution import JobExecution
from earnix_elevate.clients.data.models.metadata import Metadata
from earnix_elevate.clients.data.models.user import User


class RecipeStatusResponse(BaseModel):
    """
    `RecipeStatusResponse`

    Represents the current execution status of a recipe node within a transformation graph
    """

    start_time: Optional[datetime] = Field(
        default=None,
        alias="startTime",
        description="Date and time when the recipe execution started, null if not yet started",
    )
    end_time: Optional[datetime] = Field(
        default=None,
        alias="endTime",
        description="Date and time when the recipe execution completed, null if still running or not started",
    )
    use_sample: Optional[StrictBool] = Field(
        default=None,
        alias="useSample",
        description="Whether the recipe was executed on a sample of the data instead of the complete dataset",
    )
    last_run: Optional[datetime] = Field(
        default=None,
        alias="lastRun",
        description="Date and time when this entity was created",
    )
    run_by: Optional[User] = Field(default=None, alias="runBy")
    metadata: Optional[Metadata] = None
    execution: Optional[JobExecution] = None
    __properties = [
        "startTime",
        "endTime",
        "useSample",
        "lastRun",
        "runBy",
        "metadata",
        "execution",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> RecipeStatusResponse:
        """Create an instance of RecipeStatusResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of run_by
        if self.run_by:
            _dict["runBy"] = self.run_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict["metadata"] = self.metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of execution
        if self.execution:
            _dict["execution"] = self.execution.to_dict()
        # set to None if start_time (nullable) is None
        # and __fields_set__ contains the field
        if self.start_time is None and "start_time" in self.__fields_set__:
            _dict["startTime"] = None

        # set to None if end_time (nullable) is None
        # and __fields_set__ contains the field
        if self.end_time is None and "end_time" in self.__fields_set__:
            _dict["endTime"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> RecipeStatusResponse:
        """Create an instance of RecipeStatusResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return RecipeStatusResponse.parse_obj(obj)

        _obj = RecipeStatusResponse.parse_obj(
            {
                "start_time": obj.get("startTime"),
                "end_time": obj.get("endTime"),
                "use_sample": obj.get("useSample"),
                "last_run": obj.get("lastRun"),
                "run_by": User.from_dict(obj.get("runBy"))
                if obj.get("runBy") is not None
                else None,
                "metadata": Metadata.from_dict(obj.get("metadata"))
                if obj.get("metadata") is not None
                else None,
                "execution": JobExecution.from_dict(obj.get("execution"))
                if obj.get("execution") is not None
                else None,
            }
        )
        return _obj



# flake8: noqa

# import apis into api package
from earnix_elevate.clients.umon.api.quota_service_api import QuotaServiceApi
from earnix_elevate.clients.umon.api.usage_monitoring_service_api import (
    UsageMonitoringServiceApi,
)



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr, validator


class SinkNodeItem(BaseModel):
    """
    `SinkNodeItem`

    A single sink node in the transformation graph
    """

    node_id: Optional[StrictInt] = Field(
        default=None, alias="nodeId", description="Unique identifier of the node"
    )
    node_type: Optional[StrictStr] = Field(
        default=None, alias="nodeType", description="Type of the node"
    )
    name: Optional[StrictStr] = Field(
        default=None, description="Display name of the node"
    )
    description: Optional[StrictStr] = Field(
        default=None, description="Optional description of the node"
    )
    __properties = ["nodeId", "nodeType", "name", "description"]

    @validator("node_type")
    def node_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in (
            "TABLE",
            "RECIPE",
        ):
            raise ValueError("must be one of enum values ('TABLE', 'RECIPE')")
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SinkNodeItem:
        """Create an instance of SinkNodeItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SinkNodeItem:
        """Create an instance of SinkNodeItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SinkNodeItem.parse_obj(obj)

        _obj = SinkNodeItem.parse_obj(
            {
                "node_id": obj.get("nodeId"),
                "node_type": obj.get("nodeType"),
                "name": obj.get("name"),
                "description": obj.get("description"),
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictBool, StrictInt, StrictStr


class DatasetVersionUsage(BaseModel):
    """
    `DatasetVersionUsage`

    Information about how a recipe version is used in a specific dataset version
    """

    dataset_id: Optional[StrictInt] = Field(
        default=None, alias="datasetId", description="Unique identifier of the Dataset"
    )
    dataset_name: Optional[StrictStr] = Field(
        default=None, alias="datasetName", description="Name of the Dataset"
    )
    dataset_version_number: Optional[StrictInt] = Field(
        default=None,
        alias="datasetVersionNumber",
        description="Version number of the Dataset transformation graph",
    )
    release_status: Optional[StrictBool] = Field(
        default=None,
        alias="releaseStatus",
        description="Indicates whether this transformation graph version has been released for production use",
    )
    node_id: Optional[StrictStr] = Field(
        default=None,
        alias="nodeId",
        description="Unique identifier of the recipe node within this dataset version",
    )
    __properties = [
        "datasetId",
        "datasetName",
        "datasetVersionNumber",
        "releaseStatus",
        "nodeId",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DatasetVersionUsage:
        """Create an instance of DatasetVersionUsage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DatasetVersionUsage:
        """Create an instance of DatasetVersionUsage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DatasetVersionUsage.parse_obj(obj)

        _obj = DatasetVersionUsage.parse_obj(
            {
                "dataset_id": obj.get("datasetId"),
                "dataset_name": obj.get("datasetName"),
                "dataset_version_number": obj.get("datasetVersionNumber"),
                "release_status": obj.get("releaseStatus"),
                "node_id": obj.get("nodeId"),
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Umon API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint

from pydantic.v1 import BaseModel, Field, StrictInt, StrictStr, validator


class UsageMonitoringResponse(BaseModel):
    """
    `UsageMonitoringResponse`

    Aggregated usage metrics for a tenant
    """

    metric_type: StrictStr = Field(
        default=..., alias="metricType", description="Type of usage metric"
    )
    total_value: StrictInt = Field(
        default=...,
        alias="totalValue",
        description="Total aggregated metric value across all jobs",
    )
    __properties = ["metricType", "totalValue"]

    @validator("metric_type")
    def metric_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in (
            "DATA_TRANSFER_VOLUME_BYTES",
            "CPU_TIME_MS",
        ):
            raise ValueError(
                "must be one of enum values ('DATA_TRANSFER_VOLUME_BYTES', 'CPU_TIME_MS')"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UsageMonitoringResponse:
        """Create an instance of UsageMonitoringResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UsageMonitoringResponse:
        """Create an instance of UsageMonitoringResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UsageMonitoringResponse.parse_obj(obj)

        _obj = UsageMonitoringResponse.parse_obj(
            {"metric_type": obj.get("metricType"), "total_value": obj.get("totalValue")}
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""


from typing import List

from pydantic.v1 import Field, StrictInt, StrictStr, validate_arguments
from typing_extensions import Annotated

from earnix_elevate.clients.data.api_client import ApiClient
from earnix_elevate.clients.data.api_response import ApiResponse
from earnix_elevate.clients.data.exceptions import ApiTypeError
from earnix_elevate.clients.data.models.conversation_id_response import (
    ConversationIdResponse,
)
from earnix_elevate.clients.data.models.conversation_message_response import (
    ConversationMessageResponse,
)
from earnix_elevate.clients.data.models.conversation_response import (
    ConversationResponse,
)
from earnix_elevate.clients.data.models.recipe_code_response import RecipeCodeResponse
from earnix_elevate.clients.data.models.user_message_request import UserMessageRequest


class AiAssistantServiceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def get_active_conversation_id(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        **kwargs,
    ) -> ConversationIdResponse:
        """Retrieves the conversation ID for the current active conversation for the given dataset node (recipe).

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :return: Returns the result object.
        :rtype: ConversationIdResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_active_conversation_id_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.get_active_conversation_id_with_http_info(dataset_node_id, **kwargs)

    @validate_arguments
    def get_active_conversation_id_with_http_info(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Retrieves the conversation ID for the current active conversation for the given dataset node (recipe).

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(ConversationIdResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["dataset_node_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_active_conversation_id" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["dataset_node_id"] is not None:
            _path_params["dataset-node-id"] = _params["dataset_node_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "ConversationIdResponse",
        }

        return self.api_client.call_api(
            "/v1/ai-assistant/recipe/{dataset-node-id}/conversations/active",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_conversation_messages(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        conversation_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="Unique identifier of the conversation in the AI assistant service",
            ),
        ],
        **kwargs,
    ) -> List[ConversationMessageResponse]:
        """Retrieves all messages for the current active conversation for the given dataset node. This is useful for clients who want to continue chat in a new browser session for example.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :param conversation_id: Unique identifier of the conversation in the AI assistant service (required)
        :type conversation_id: str
        :return: Returns the result object.
        :rtype: List[ConversationMessageResponse]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_conversation_messages_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.get_conversation_messages_with_http_info(
            dataset_node_id, conversation_id, **kwargs
        )

    @validate_arguments
    def get_conversation_messages_with_http_info(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        conversation_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="Unique identifier of the conversation in the AI assistant service",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Retrieves all messages for the current active conversation for the given dataset node. This is useful for clients who want to continue chat in a new browser session for example.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :param conversation_id: Unique identifier of the conversation in the AI assistant service (required)
        :type conversation_id: str
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(List[ConversationMessageResponse], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["dataset_node_id", "conversation_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_conversation_messages" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["dataset_node_id"] is not None:
            _path_params["dataset-node-id"] = _params["dataset_node_id"]

        if _params["conversation_id"] is not None:
            _path_params["conversation-id"] = _params["conversation_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "List[ConversationMessageResponse]",
        }

        return self.api_client.call_api(
            "/v1/ai-assistant/recipe/{dataset-node-id}/conversations/{conversation-id}/messages",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_dataset_recipe_node_entity_code(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        **kwargs,
    ) -> RecipeCodeResponse:
        """Retrieves the actual (saved in DB) recipe code for the given dataset node (recipe). This allows clients to view or copy the code generated by the AI assistant.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :return: Returns the result object.
        :rtype: RecipeCodeResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_dataset_recipe_node_entity_code_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.get_dataset_recipe_node_entity_code_with_http_info(
            dataset_node_id, **kwargs
        )

    @validate_arguments
    def get_dataset_recipe_node_entity_code_with_http_info(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Retrieves the actual (saved in DB) recipe code for the given dataset node (recipe). This allows clients to view or copy the code generated by the AI assistant.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(RecipeCodeResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["dataset_node_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_dataset_recipe_node_entity_code" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["dataset_node_id"] is not None:
            _path_params["dataset-node-id"] = _params["dataset_node_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "RecipeCodeResponse",
        }

        return self.api_client.call_api(
            "/v1/ai-assistant/recipe/{dataset-node-id}/recipe-code",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_conversations(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        **kwargs,
    ) -> List[ConversationResponse]:
        """Retrieves all conversations for the given dataset node (recipe). This is useful for clients who want to list all conversations and allow the user to select one to continue.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :return: Returns the result object.
        :rtype: List[ConversationResponse]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the list_conversations_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.list_conversations_with_http_info(dataset_node_id, **kwargs)

    @validate_arguments
    def list_conversations_with_http_info(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Retrieves all conversations for the given dataset node (recipe). This is useful for clients who want to list all conversations and allow the user to select one to continue.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(List[ConversationResponse], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["dataset_node_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_conversations" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["dataset_node_id"] is not None:
            _path_params["dataset-node-id"] = _params["dataset_node_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "List[ConversationResponse]",
        }

        return self.api_client.call_api(
            "/v1/ai-assistant/recipe/{dataset-node-id}/conversations",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def start_new_conversation(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        **kwargs,
    ) -> ConversationIdResponse:
        """Atomically archives any existing active conversation and starts a new one that is empty. This is called when the user wants to start from scratch.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :return: Returns the result object.
        :rtype: ConversationIdResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the start_new_conversation_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.start_new_conversation_with_http_info(dataset_node_id, **kwargs)

    @validate_arguments
    def start_new_conversation_with_http_info(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Atomically archives any existing active conversation and starts a new one that is empty. This is called when the user wants to start from scratch.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(ConversationIdResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["dataset_node_id"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_new_conversation" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["dataset_node_id"] is not None:
            _path_params["dataset-node-id"] = _params["dataset_node_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "201": "ConversationIdResponse",
        }

        return self.api_client.call_api(
            "/v1/ai-assistant/recipe/{dataset-node-id}/conversations",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def submit_message_to_conversation(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        conversation_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="Unique identifier of the conversation in the AI assistant service",
            ),
        ],
        user_message_request: Annotated[
            UserMessageRequest,
            Field(
                ...,
                description="Request body containing the user message to be added to the conversation",
            ),
        ],
        **kwargs,
    ) -> None:
        """Submits a new message to the current active conversation for the given dataset node. This is used to send user messages to the chat.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :param conversation_id: Unique identifier of the conversation in the AI assistant service (required)
        :type conversation_id: str
        :param user_message_request: Request body containing the user message to be added to the conversation (required)
        :type user_message_request: UserMessageRequest
        :return: Returns the result object.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the submit_message_to_conversation_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.submit_message_to_conversation_with_http_info(
            dataset_node_id, conversation_id, user_message_request, **kwargs
        )

    @validate_arguments
    def submit_message_to_conversation_with_http_info(
        self,
        dataset_node_id: Annotated[
            StrictInt,
            Field(
                ...,
                description="Unique identifier of the node within the transformation graph",
            ),
        ],
        conversation_id: Annotated[
            StrictStr,
            Field(
                ...,
                description="Unique identifier of the conversation in the AI assistant service",
            ),
        ],
        user_message_request: Annotated[
            UserMessageRequest,
            Field(
                ...,
                description="Request body containing the user message to be added to the conversation",
            ),
        ],
        **kwargs,
    ) -> ApiResponse:
        """Submits a new message to the current active conversation for the given dataset node. This is used to send user messages to the chat.

        :param dataset_node_id: Unique identifier of the node within the transformation graph (required)
        :type dataset_node_id: int
        :param conversation_id: Unique identifier of the conversation in the AI assistant service (required)
        :type conversation_id: str
        :param user_message_request: Request body containing the user message to be added to the conversation (required)
        :type user_message_request: UserMessageRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: None
        """

        _params = locals()

        _all_params = ["dataset_node_id", "conversation_id", "user_message_request"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submit_message_to_conversation" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["dataset_node_id"] is not None:
            _path_params["dataset-node-id"] = _params["dataset_node_id"]

        if _params["conversation_id"] is not None:
            _path_params["conversation-id"] = _params["conversation_id"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["user_message_request"] is not None:
            _body_params = _params["user_message_request"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {}

        return self.api_client.call_api(
            "/v1/ai-assistant/recipe/{dataset-node-id}/conversations/{conversation-id}/messages",
            "POST",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from datetime import datetime
from typing import Any, Dict, Optional

from pydantic.v1 import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist

from earnix_elevate.clients.imx.models.job_execution import JobExecution
from earnix_elevate.clients.imx.models.user import User


class ExportResponse(BaseModel):
    """
    `ExportResponse`

    Response containing Export
    """

    id: Optional[StrictInt] = Field(
        default=None, description="Unique identifier for the export operation"
    )
    job_id: Optional[StrictStr] = Field(
        default=None,
        alias="jobId",
        description="The job ID associated with the export operation",
    )
    target_id: Optional[StrictInt] = Field(
        default=None,
        alias="targetId",
        description="The dataTarget ID that specifies the location to export the data",
    )
    target_name: Optional[StrictStr] = Field(
        default=None,
        alias="targetName",
        description="The name of the dataTarget that specifies the location to export the data",
    )
    data_target_details: Optional[Dict[str, Any]] = Field(
        default=None,
        alias="dataTargetDetails",
        description="The details of the data target (e.g., S3 bucket path or PriceIt table path)",
    )
    exported_table_name: Optional[StrictStr] = Field(
        default=None,
        alias="exportedTableName",
        description="The name of the exported table",
    )
    source_type: Optional[StrictStr] = Field(
        default=None,
        alias="sourceType",
        description="The type of data source to export (dataset for DataSet, datatable for DataTable)",
    )
    source_id: Optional[StrictInt] = Field(
        default=None,
        alias="sourceId",
        description="The ID of the source to export (DataSet ID or DataTable ID)",
    )
    source_version: Optional[StrictInt] = Field(
        default=None,
        alias="sourceVersion",
        description="The specific version of the source to export.",
    )
    source_name: Optional[StrictStr] = Field(
        default=None,
        alias="sourceName",
        description="The name of the source to export (DataSet name or DataTable name)",
    )
    use_sample: Optional[StrictBool] = Field(
        default=False,
        alias="useSample",
        description="Whether to export a sample of the data (true) or the full data (false). Default is false.",
    )
    validate_to_release: Optional[StrictBool] = Field(
        default=True,
        alias="validateToRelease",
        description="Whether to validate the data before exporting. Default is true.",
    )
    cast_boolean_to_integer: Optional[StrictBool] = Field(
        default=False,
        alias="castBooleanToInteger",
        description="Whether to cast boolean columns to integer (1/0) during export. Default is false.",
    )
    columns: Optional[conlist(StrictStr)] = Field(
        default=None,
        description="Optional list of specific columns to include in the export. If not provided, all columns are exported.",
    )
    connection_id: Optional[StrictInt] = Field(
        default=None,
        alias="connectionId",
        description="The unique identifier of the Connection used for this export",
    )
    connection_name: Optional[StrictStr] = Field(
        default=None,
        alias="connectionName",
        description="The name of the Connection used for this export",
    )
    execution: Optional[JobExecution] = None
    created_by: Optional[User] = Field(default=None, alias="createdBy")
    created_date: Optional[datetime] = Field(
        default=None,
        alias="createdDate",
        description="The date and time when the entity was created",
    )
    last_modified_by: Optional[User] = Field(default=None, alias="lastModifiedBy")
    last_modified_date: Optional[datetime] = Field(
        default=None,
        alias="lastModifiedDate",
        description="The date and time when the entity was last modified",
    )
    __properties = [
        "id",
        "jobId",
        "targetId",
        "targetName",
        "dataTargetDetails",
        "exportedTableName",
        "sourceType",
        "sourceId",
        "sourceVersion",
        "sourceName",
        "useSample",
        "validateToRelease",
        "castBooleanToInteger",
        "columns",
        "connectionId",
        "connectionName",
        "execution",
        "createdBy",
        "createdDate",
        "lastModifiedBy",
        "lastModifiedDate",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExportResponse:
        """Create an instance of ExportResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of execution
        if self.execution:
            _dict["execution"] = self.execution.to_dict()
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict["createdBy"] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of last_modified_by
        if self.last_modified_by:
            _dict["lastModifiedBy"] = self.last_modified_by.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExportResponse:
        """Create an instance of ExportResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExportResponse.parse_obj(obj)

        _obj = ExportResponse.parse_obj(
            {
                "id": obj.get("id"),
                "job_id": obj.get("jobId"),
                "target_id": obj.get("targetId"),
                "target_name": obj.get("targetName"),
                "data_target_details": obj.get("dataTargetDetails"),
                "exported_table_name": obj.get("exportedTableName"),
                "source_type": obj.get("sourceType"),
                "source_id": obj.get("sourceId"),
                "source_version": obj.get("sourceVersion"),
                "source_name": obj.get("sourceName"),
                "use_sample": obj.get("useSample")
                if obj.get("useSample") is not None
                else False,
                "validate_to_release": obj.get("validateToRelease")
                if obj.get("validateToRelease") is not None
                else True,
                "cast_boolean_to_integer": obj.get("castBooleanToInteger")
                if obj.get("castBooleanToInteger") is not None
                else False,
                "columns": obj.get("columns"),
                "connection_id": obj.get("connectionId"),
                "connection_name": obj.get("connectionName"),
                "execution": JobExecution.from_dict(obj.get("execution"))
                if obj.get("execution") is not None
                else None,
                "created_by": User.from_dict(obj.get("createdBy"))
                if obj.get("createdBy") is not None
                else None,
                "created_date": obj.get("createdDate"),
                "last_modified_by": User.from_dict(obj.get("lastModifiedBy"))
                if obj.get("lastModifiedBy") is not None
                else None,
                "last_modified_date": obj.get("lastModifiedDate"),
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint

from pydantic.v1 import Field

from earnix_elevate.clients.imx.models.o_auth_request import OAuthRequest
from earnix_elevate.clients.imx.models.update_connection_request import (
    UpdateConnectionRequest,
)


class UpdatePriceItDimConnectionRequest(UpdateConnectionRequest):
    """
    `UpdatePriceItDimConnectionRequest`

    Request to update a Price-it DIM Connection, allowing modification of authentication credentials.
    """

    auth: OAuthRequest = Field(...)
    __properties = ["id", "lockVersion", "name", "description", "tags", "type", "auth"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> UpdatePriceItDimConnectionRequest:
        """Create an instance of UpdatePriceItDimConnectionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of auth
        if self.auth:
            _dict["auth"] = self.auth.to_dict()
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> UpdatePriceItDimConnectionRequest:
        """Create an instance of UpdatePriceItDimConnectionRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return UpdatePriceItDimConnectionRequest.parse_obj(obj)

        _obj = UpdatePriceItDimConnectionRequest.parse_obj(
            {
                "id": obj.get("id"),
                "lock_version": obj.get("lockVersion"),
                "name": obj.get("name"),
                "description": obj.get("description"),
                "tags": obj.get("tags"),
                "type": obj.get("type"),
                "auth": OAuthRequest.from_dict(obj.get("auth"))
                if obj.get("auth") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

# flake8: noqa
"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

# import models into model package
from earnix_elevate.clients.data.models.add_dataset_data_table_node_request import (
    AddDatasetDataTableNodeRequest,
)
from earnix_elevate.clients.data.models.add_dataset_node_request import (
    AddDatasetNodeRequest,
)
from earnix_elevate.clients.data.models.add_dataset_recipe_node_request import (
    AddDatasetRecipeNodeRequest,
)
from earnix_elevate.clients.data.models.connection_details import ConnectionDetails
from earnix_elevate.clients.data.models.conversation_id_response import (
    ConversationIdResponse,
)
from earnix_elevate.clients.data.models.conversation_message_response import (
    ConversationMessageResponse,
)
from earnix_elevate.clients.data.models.conversation_response import (
    ConversationResponse,
)
from earnix_elevate.clients.data.models.create_data_table_request import (
    CreateDataTableRequest,
)
from earnix_elevate.clients.data.models.create_dataset_request import (
    CreateDatasetRequest,
)
from earnix_elevate.clients.data.models.create_dataset_version_request import (
    CreateDatasetVersionRequest,
)
from earnix_elevate.clients.data.models.create_recipe_request import CreateRecipeRequest
from earnix_elevate.clients.data.models.create_recipe_version_request import (
    CreateRecipeVersionRequest,
)
from earnix_elevate.clients.data.models.data_table_response import DataTableResponse
from earnix_elevate.clients.data.models.data_tables_response import DataTablesResponse
from earnix_elevate.clients.data.models.data_version_response import DataVersionResponse
from earnix_elevate.clients.data.models.dataset_data_table_node_response import (
    DatasetDataTableNodeResponse,
)
from earnix_elevate.clients.data.models.dataset_edge_response import DatasetEdgeResponse
from earnix_elevate.clients.data.models.dataset_edges_response import (
    DatasetEdgesResponse,
)
from earnix_elevate.clients.data.models.dataset_node_response import DatasetNodeResponse
from earnix_elevate.clients.data.models.dataset_nodes_response import (
    DatasetNodesResponse,
)
from earnix_elevate.clients.data.models.dataset_recipe_node_response import (
    DatasetRecipeNodeResponse,
)
from earnix_elevate.clients.data.models.dataset_response import DatasetResponse
from earnix_elevate.clients.data.models.dataset_version_usage import DatasetVersionUsage
from earnix_elevate.clients.data.models.datasets_response import DatasetsResponse
from earnix_elevate.clients.data.models.execute_recipe_request import (
    ExecuteRecipeRequest,
)
from earnix_elevate.clients.data.models.export_part_result_pair_response import (
    ExportPartResultPairResponse,
)
from earnix_elevate.clients.data.models.export_s3_job_status_response import (
    ExportS3JobStatusResponse,
)
from earnix_elevate.clients.data.models.export_s3_part_job_status_response import (
    ExportS3PartJobStatusResponse,
)
from earnix_elevate.clients.data.models.export_s3_part_request import (
    ExportS3PartRequest,
)
from earnix_elevate.clients.data.models.export_s3_part_response import (
    ExportS3PartResponse,
)
from earnix_elevate.clients.data.models.export_s3_request import ExportS3Request
from earnix_elevate.clients.data.models.export_s3_response import ExportS3Response
from earnix_elevate.clients.data.models.export_s3_status_response import (
    ExportS3StatusResponse,
)
from earnix_elevate.clients.data.models.job_error import JobError
from earnix_elevate.clients.data.models.job_execution import JobExecution
from earnix_elevate.clients.data.models.job_progress import JobProgress
from earnix_elevate.clients.data.models.job_stage import JobStage
from earnix_elevate.clients.data.models.job_status import JobStatus
from earnix_elevate.clients.data.models.lean_transformation_graph_response import (
    LeanTransformationGraphResponse,
)
from earnix_elevate.clients.data.models.list_query import ListQuery
from earnix_elevate.clients.data.models.metadata import Metadata
from earnix_elevate.clients.data.models.problem_detail import ProblemDetail
from earnix_elevate.clients.data.models.recipe_code_response import RecipeCodeResponse
from earnix_elevate.clients.data.models.recipe_response import RecipeResponse
from earnix_elevate.clients.data.models.recipe_status_response import (
    RecipeStatusResponse,
)
from earnix_elevate.clients.data.models.recipe_version import RecipeVersion
from earnix_elevate.clients.data.models.recipe_version_response import (
    RecipeVersionResponse,
)
from earnix_elevate.clients.data.models.recipes_response import RecipesResponse
from earnix_elevate.clients.data.models.schema_analysis_status_response import (
    SchemaAnalysisStatusResponse,
)
from earnix_elevate.clients.data.models.sink_node_item import SinkNodeItem
from earnix_elevate.clients.data.models.sink_nodes_response import SinkNodesResponse
from earnix_elevate.clients.data.models.source_node_definition import (
    SourceNodeDefinition,
)
from earnix_elevate.clients.data.models.transformation_graph_response import (
    TransformationGraphResponse,
)
from earnix_elevate.clients.data.models.transformation_graph_wrapper_response import (
    TransformationGraphWrapperResponse,
)
from earnix_elevate.clients.data.models.update_data_table_request import (
    UpdateDataTableRequest,
)
from earnix_elevate.clients.data.models.update_dataset_data_table_node_request import (
    UpdateDatasetDataTableNodeRequest,
)
from earnix_elevate.clients.data.models.update_dataset_node_request import (
    UpdateDatasetNodeRequest,
)
from earnix_elevate.clients.data.models.update_dataset_recipe_node_request import (
    UpdateDatasetRecipeNodeRequest,
)
from earnix_elevate.clients.data.models.update_dataset_request import (
    UpdateDatasetRequest,
)
from earnix_elevate.clients.data.models.update_recipe_request import UpdateRecipeRequest
from earnix_elevate.clients.data.models.update_recipe_version_request import (
    UpdateRecipeVersionRequest,
)
from earnix_elevate.clients.data.models.user import User
from earnix_elevate.clients.data.models.user_message_request import UserMessageRequest



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field

from earnix_elevate.clients.data.models.job_error import JobError
from earnix_elevate.clients.data.models.job_progress import JobProgress
from earnix_elevate.clients.data.models.job_status import JobStatus


class JobExecution(BaseModel):
    """
    `JobExecution`

    Job execution status, progress, and error information. Reusable across all job types.
    """

    status: JobStatus = Field(...)
    progress: Optional[JobProgress] = None
    error: Optional[JobError] = None
    __properties = ["status", "progress", "error"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> JobExecution:
        """Create an instance of JobExecution from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of progress
        if self.progress:
            _dict["progress"] = self.progress.to_dict()
        # override the default output from pydantic by calling `to_dict()` of error
        if self.error:
            _dict["error"] = self.error.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> JobExecution:
        """Create an instance of JobExecution from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return JobExecution.parse_obj(obj)

        _obj = JobExecution.parse_obj(
            {
                "status": obj.get("status"),
                "progress": JobProgress.from_dict(obj.get("progress"))
                if obj.get("progress") is not None
                else None,
                "error": JobError.from_dict(obj.get("error"))
                if obj.get("error") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Umon API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""


from datetime import datetime
from typing import Optional

from pydantic.v1 import Field, StrictStr, validate_arguments
from typing_extensions import Annotated

from earnix_elevate.clients.umon.api_client import ApiClient
from earnix_elevate.clients.umon.api_response import ApiResponse
from earnix_elevate.clients.umon.exceptions import ApiTypeError
from earnix_elevate.clients.umon.models.usage_monitoring_response import (
    UsageMonitoringResponse,
)


class UsageMonitoringServiceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def download_usage_metrics_csv(
        self,
        metric_type: Annotated[
            StrictStr,
            Field(
                ...,
                description="Type of usage metric to aggregate. Supported types are DATA_TRANSFER_VOLUME_BYTES (total bytes transferred) and CPU_TIME_MS (total CPU time in milliseconds).",
            ),
        ],
        start_date: Annotated[
            Optional[datetime], Field(description="Start of date range")
        ] = None,
        end_date: Annotated[
            Optional[datetime], Field(description="End of date range")
        ] = None,
        **kwargs,
    ) -> bytearray:
        """Downloads detailed usage metrics as CSV stream. Returns all usage aggregation records matching the specified metric type and date range. The CSV includes all entity fields including tenant ID, job details, metric values, and metric-specific details in JSON format. Data is streamed in pages to support large downloads efficiently.

        :param metric_type: Type of usage metric to aggregate. Supported types are DATA_TRANSFER_VOLUME_BYTES (total bytes transferred) and CPU_TIME_MS (total CPU time in milliseconds). (required)
        :type metric_type: str
        :param start_date: Start of date range
        :type start_date: datetime
        :param end_date: End of date range
        :type end_date: datetime
        :return: Returns the result object.
        :rtype: bytearray
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the download_usage_metrics_csv_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.download_usage_metrics_csv_with_http_info(
            metric_type, start_date, end_date, **kwargs
        )

    @validate_arguments
    def download_usage_metrics_csv_with_http_info(
        self,
        metric_type: Annotated[
            StrictStr,
            Field(
                ...,
                description="Type of usage metric to aggregate. Supported types are DATA_TRANSFER_VOLUME_BYTES (total bytes transferred) and CPU_TIME_MS (total CPU time in milliseconds).",
            ),
        ],
        start_date: Annotated[
            Optional[datetime], Field(description="Start of date range")
        ] = None,
        end_date: Annotated[
            Optional[datetime], Field(description="End of date range")
        ] = None,
        **kwargs,
    ) -> ApiResponse:
        """Downloads detailed usage metrics as CSV stream. Returns all usage aggregation records matching the specified metric type and date range. The CSV includes all entity fields including tenant ID, job details, metric values, and metric-specific details in JSON format. Data is streamed in pages to support large downloads efficiently.

        :param metric_type: Type of usage metric to aggregate. Supported types are DATA_TRANSFER_VOLUME_BYTES (total bytes transferred) and CPU_TIME_MS (total CPU time in milliseconds). (required)
        :type metric_type: str
        :param start_date: Start of date range
        :type start_date: datetime
        :param end_date: End of date range
        :type end_date: datetime
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(bytearray, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["metric_type", "start_date", "end_date"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_usage_metrics_csv" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get("metric_type") is not None:
            _query_params.append(("metricType", _params["metric_type"]))

        if _params.get("start_date") is not None:
            if isinstance(_params["start_date"], datetime):
                _query_params.append(
                    (
                        "startDate",
                        _params["start_date"].strftime(
                            self.api_client.configuration.datetime_format
                        ),
                    )
                )
            else:
                _query_params.append(("startDate", _params["start_date"]))

        if _params.get("end_date") is not None:
            if isinstance(_params["end_date"], datetime):
                _query_params.append(
                    (
                        "endDate",
                        _params["end_date"].strftime(
                            self.api_client.configuration.datetime_format
                        ),
                    )
                )
            else:
                _query_params.append(("endDate", _params["end_date"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["text/csv", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "bytearray",
        }

        return self.api_client.call_api(
            "/v1/usage-metrics/download",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_usage_summary(
        self,
        metric_type: Annotated[
            StrictStr,
            Field(
                ...,
                description="Type of usage metric to aggregate. Supported types are DATA_TRANSFER_VOLUME_BYTES (total bytes transferred) and CPU_TIME_MS (total CPU time in milliseconds).",
            ),
        ],
        start_date: Annotated[
            Optional[datetime], Field(description="Start of date range")
        ] = None,
        end_date: Annotated[
            Optional[datetime], Field(description="End of date range")
        ] = None,
        **kwargs,
    ) -> UsageMonitoringResponse:
        """Retrieves aggregated usage metrics for the current tenant. This API requires the metricType query parameter (DATA_TRANSFER_VOLUME_BYTES or CPU_TIME_MS). Returns a UsageMonitoringResponse object containing metricType and totalValue fields, providing the total aggregated metric value across all jobs for monitoring resource consumption and usage patterns.

        :param metric_type: Type of usage metric to aggregate. Supported types are DATA_TRANSFER_VOLUME_BYTES (total bytes transferred) and CPU_TIME_MS (total CPU time in milliseconds). (required)
        :type metric_type: str
        :param start_date: Start of date range
        :type start_date: datetime
        :param end_date: End of date range
        :type end_date: datetime
        :return: Returns the result object.
        :rtype: UsageMonitoringResponse
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            message = "Error! Please call the get_usage_summary_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            raise ValueError(message)
        return self.get_usage_summary_with_http_info(
            metric_type, start_date, end_date, **kwargs
        )

    @validate_arguments
    def get_usage_summary_with_http_info(
        self,
        metric_type: Annotated[
            StrictStr,
            Field(
                ...,
                description="Type of usage metric to aggregate. Supported types are DATA_TRANSFER_VOLUME_BYTES (total bytes transferred) and CPU_TIME_MS (total CPU time in milliseconds).",
            ),
        ],
        start_date: Annotated[
            Optional[datetime], Field(description="Start of date range")
        ] = None,
        end_date: Annotated[
            Optional[datetime], Field(description="End of date range")
        ] = None,
        **kwargs,
    ) -> ApiResponse:
        """Retrieves aggregated usage metrics for the current tenant. This API requires the metricType query parameter (DATA_TRANSFER_VOLUME_BYTES or CPU_TIME_MS). Returns a UsageMonitoringResponse object containing metricType and totalValue fields, providing the total aggregated metric value across all jobs for monitoring resource consumption and usage patterns.

        :param metric_type: Type of usage metric to aggregate. Supported types are DATA_TRANSFER_VOLUME_BYTES (total bytes transferred) and CPU_TIME_MS (total CPU time in milliseconds). (required)
        :type metric_type: str
        :param start_date: Start of date range
        :type start_date: datetime
        :param end_date: End of date range
        :type end_date: datetime
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
        :rtype: tuple(UsageMonitoringResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["metric_type", "start_date", "end_date"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_usage_summary" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get("metric_type") is not None:
            _query_params.append(("metricType", _params["metric_type"]))

        if _params.get("start_date") is not None:
            if isinstance(_params["start_date"], datetime):
                _query_params.append(
                    (
                        "startDate",
                        _params["start_date"].strftime(
                            self.api_client.configuration.datetime_format
                        ),
                    )
                )
            else:
                _query_params.append(("startDate", _params["start_date"]))

        if _params.get("end_date") is not None:
            if isinstance(_params["end_date"], datetime):
                _query_params.append(
                    (
                        "endDate",
                        _params["end_date"].strftime(
                            self.api_client.configuration.datetime_format
                        ),
                    )
                )
            else:
                _query_params.append(("endDate", _params["end_date"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )

        # authentication setting
        _auth_settings = ["BearerAuth"]

        _response_types_map = {
            "200": "UsageMonitoringResponse",
        }

        return self.api_client.call_api(
            "/v1/usage-metrics",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import (
    BaseModel,
    Field,
    StrictBool,
    StrictStr,
    conlist,
    constr,
    validator,
)

from earnix_elevate.clients.data.models.recipe_version import RecipeVersion


class CreateRecipeRequest(BaseModel):
    """
    `CreateRecipeRequest`

    Creates a new recipe with version 1
    """

    name: constr(strict=True, max_length=100, min_length=3) = Field(
        default=...,
        description="Name of the entity for identification and display purposes",
    )
    description: Optional[constr(strict=True, max_length=500)] = Field(
        default=None,
        description="Optional detailed description providing additional context about the entity",
    )
    tags: Optional[conlist(StrictStr, unique_items=True)] = Field(
        default=None,
        description="List of unique tags for categorizing and organizing the entity",
    )
    shared: Optional[StrictBool] = True
    language: Optional[StrictStr] = Field(
        default=None, description="Recipe language (shared across all versions)"
    )
    aliases: conlist(
        constr(strict=True, max_length=64, min_length=1), max_items=10, min_items=1
    ) = Field(
        default=...,
        description='Table aliases used in SQL code for recipe transformations. Single-source recipes have 1 alias (e.g. "CurrentTable" for backward compatibility, or any valid name). Multi-source recipes have 2-10 aliases matching table names in SQL. ',
    )
    recipe_version: RecipeVersion = Field(default=..., alias="recipeVersion")
    __properties = [
        "name",
        "description",
        "tags",
        "shared",
        "language",
        "aliases",
        "recipeVersion",
    ]

    @validator("language")
    def language_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ("SQL",):
            raise ValueError("must be one of enum values ('SQL')")
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateRecipeRequest:
        """Create an instance of CreateRecipeRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of recipe_version
        if self.recipe_version:
            _dict["recipeVersion"] = self.recipe_version.to_dict()
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateRecipeRequest:
        """Create an instance of CreateRecipeRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CreateRecipeRequest.parse_obj(obj)

        _obj = CreateRecipeRequest.parse_obj(
            {
                "name": obj.get("name"),
                "description": obj.get("description"),
                "tags": obj.get("tags"),
                "shared": obj.get("shared") if obj.get("shared") is not None else True,
                "language": obj.get("language"),
                "aliases": obj.get("aliases"),
                "recipe_version": RecipeVersion.from_dict(obj.get("recipeVersion"))
                if obj.get("recipeVersion") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json

from aenum import Enum


class JobStatus(str, Enum):
    """
    `JobStatus`

    Job status common to all job types
    """

    """
    allowed enum values
    """
    PENDING = "PENDING"
    SUBMITTED = "SUBMITTED"
    RUNNING = "RUNNING"
    SUCCEEDED = "SUCCEEDED"
    FAILED = "FAILED"
    CANCELLED = "CANCELLED"

    @classmethod
    def from_json(cls, json_str: str) -> JobStatus:
        """Create an instance of JobStatus from a JSON string"""
        return JobStatus(json.loads(json_str))



# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
import re
from typing import Optional

from pydantic.v1 import Field, constr, validator

from earnix_elevate.clients.imx.models.data_target_response import DataTargetResponse
from earnix_elevate.clients.imx.models.user import User


class PriceItDataTargetResponse(DataTargetResponse):
    """
    `PriceItDataTargetResponse`

    Response for an PriceIt Target that provides access to PriceIt table distanation.
    """

    project_path: Optional[constr(strict=True, max_length=500, min_length=3)] = Field(
        default=None,
        alias="projectPath",
        description="The project path within PriceIt where the data will be exported",
    )
    table_path: Optional[constr(strict=True, max_length=500, min_length=3)] = Field(
        default=None,
        alias="tablePath",
        description="The table path within PriceIt where the data will be exported",
    )
    table_name: Optional[constr(strict=True, max_length=1000, min_length=3)] = Field(
        default=None,
        alias="tableName",
        description="The table name within PriceIt where the data will be exported",
    )
    __properties = [
        "id",
        "lockVersion",
        "connectionId",
        "name",
        "description",
        "tags",
        "createdBy",
        "createdDate",
        "lastModifiedBy",
        "lastModifiedDate",
        "type",
        "connectionName",
        "projectPath",
        "tablePath",
        "tableName",
    ]

    @validator("project_path")
    def project_path_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[A-Za-z0-9\/*+= _&$()%\-\.,<>≤≥\\]*$", value):
            raise ValueError(
                r"must validate the regular expression /^[A-Za-z0-9\/*+= _&$()%\-\.,<>≤≥\\]*$/"
            )
        return value

    @validator("table_path")
    def table_path_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[A-Za-z0-9\/*+= _&$()%\-\.,<>≤≥\\]*$", value):
            raise ValueError(
                r"must validate the regular expression /^[A-Za-z0-9\/*+= _&$()%\-\.,<>≤≥\\]*$/"
            )
        return value

    @validator("table_name")
    def table_name_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[A-Za-z0-9\/*+= _&$()%\-\.,<>≤≥{}]*$", value):
            raise ValueError(
                r"must validate the regular expression /^[A-Za-z0-9\/*+= _&$()%\-\.,<>≤≥{}]*$/"
            )
        return value

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PriceItDataTargetResponse:
        """Create an instance of PriceItDataTargetResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict["createdBy"] = self.created_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of last_modified_by
        if self.last_modified_by:
            _dict["lastModifiedBy"] = self.last_modified_by.to_dict()
        # set to None if description (nullable) is None
        # and __fields_set__ contains the field
        if self.description is None and "description" in self.__fields_set__:
            _dict["description"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PriceItDataTargetResponse:
        """Create an instance of PriceItDataTargetResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PriceItDataTargetResponse.parse_obj(obj)

        _obj = PriceItDataTargetResponse.parse_obj(
            {
                "id": obj.get("id"),
                "lock_version": obj.get("lockVersion"),
                "connection_id": obj.get("connectionId"),
                "name": obj.get("name"),
                "description": obj.get("description"),
                "tags": obj.get("tags"),
                "created_by": User.from_dict(obj.get("createdBy"))
                if obj.get("createdBy") is not None
                else None,
                "created_date": obj.get("createdDate"),
                "last_modified_by": User.from_dict(obj.get("lastModifiedBy"))
                if obj.get("lastModifiedBy") is not None
                else None,
                "last_modified_date": obj.get("lastModifiedDate"),
                "type": obj.get("type"),
                "connection_name": obj.get("connectionName"),
                "project_path": obj.get("projectPath"),
                "table_path": obj.get("tablePath"),
                "table_name": obj.get("tableName"),
            }
        )
        return _obj
